pub enum DateError {
InvalidDay(i64),
InvalidMonth(i64),
InvalidYear(i64),
InvalidFields,
}Expand description
Errors that can arise in relation to a Date
Variants
InvalidDay(i64)
The day number is not allowed (must be 1 <= day <= 31)
InvalidMonth(i64)
The month number is not allowed (must be 1 <= day <= 12)
InvalidYear(i64)
InvalidFields
Invalid field initialisation. e.g. the day has been set without the month also being set