Entity

Struct Entity 

pub struct Entity { /* private fields */ }
The OpenTimeline Entity type

Implementations

Source

impl Entity

pub fn from( id: Option<OpenTimelineId>, name: Name, start: Date, end: Option<Date>, tags: Option<Tags>, ) -> Result<Entity, EntityError>

Create a valid OpenTimeline Entity if it is possible to do so with the values passed in

pub fn clear_id(&mut self)

Clear the Entity’s ID

pub fn tags(&self) -> &Option<Tags>

Borrow the entity’s Tags

pub fn tags_mut(&mut self) -> &mut Option<Tags>

Mutably borrow the entity’s Tags

pub fn add_tag(&mut self, tag: Tag)

Add a tag to the entity

pub fn remove_tag(&mut self, tag: &Tag)

Remove a tag from the entity

pub fn set_tags(&mut self, tags: Tags)

Set the entity’s Tags

pub fn clear_tags(&mut self)

Clear the entity’s Tags and set to None

pub fn start(&self) -> Date

Get the entity’s start Date

pub fn set_start(&mut self, start: Date) -> Result<(), EntityError>

Set the entity’s start Date if it’ll be valid

pub fn end(&self) -> Option<Date>

Get the entity’s end Date

pub fn set_end(&mut self, end: Date) -> Result<(), EntityError>

Set the entity’s end Date if it’ll be valid

pub fn end_year_is_set(&self) -> bool

Check if the entity’s end year is set

pub fn end_year(&self) -> Option<Year>

Check if the entity’s end year is set

pub fn end_month(&self) -> Option<Month>

Check if the entity’s end month is set

pub fn end_day(&self) -> Option<Day>

Check if the entity’s end day is set

pub fn start_year(&self) -> Year

Check if the entity’s start year is set

pub fn start_month(&self) -> Option<Month>

Check if the entity’s start month is set

pub fn start_day(&self) -> Option<Day>

Check if the entity’s start day is set

pub fn matches_bool_tag_expr(&self, bool_tag_expr: &BoolTagExpr) -> bool

Whether the entity in question matches the boolean tag expression. This can be used to filter a list of entities by a boolean tag expression.