pub struct Name(/* private fields */);Expand description
The OpenTimeline Name type. The value can be any string apart from one
which when trimmed of trailing and leading whitespace is empty.
Implementations