Date

Struct Date 

pub struct Date { /* private fields */ }
The OpenTimeline date type

The year field must be set but the day and month fields are optional. If the day field is set the month field must be set, but if the month field is set, the day field is optional.

Implementations

Source

impl Date

pub fn today() -> Self

Today’s date

pub fn from( day: Option<i64>, month: Option<i64>, year: i64, ) -> Result<Date, DateError>

Create a new Date if the result will be valid

pub fn as_long_date_format(&self) -> String

e.g. 1st Jan 2025 format

pub fn as_short_date_format(&self) -> String

dd/mm/yyyy format

pub fn set_day(&mut self, day: Option<i64>) -> Result<(), DateError>

Update an existing Date’s day if the result will be valid

pub fn set_month(&mut self, month: Option<i64>) -> Result<(), DateError>

Update an existing Date’s month if the result will be valid

pub fn set_year(&mut self, year: i64) -> Result<(), DateError>

Update an existing Date’s year if the result will be valid

pub fn day(&self) -> Option<Day>

Get the Date’s day

pub fn month(&self) -> Option<Month>

Get the Date’s month

pub fn year(&self) -> Year

Get the Date’s year