pub struct Entity { /* private fields */ }Expand description
The OpenTimeline Entity type
Implementations
Sourceimpl Entity
impl Entity
Sourcepub fn from(
id: Option<OpenTimelineId>,
name: Name,
start: Date,
end: Option<Date>,
tags: Option<Tags>,
) -> Result<Entity, EntityError>
pub fn from( id: Option<OpenTimelineId>, name: Name, start: Date, end: Option<Date>, tags: Option<Tags>, ) -> Result<Entity, EntityError>
Create a valid OpenTimeline Entity if it is possible to do so with
the values passed in
Borrow the entity’s Tags
Mutably borrow the entity’s Tags
Sourcepub fn remove_tag(&mut self, tag: &Tag)
pub fn remove_tag(&mut self, tag: &Tag)
Remove a tag from the entity
Set the entity’s Tags
Clear the entity’s Tags and set to None
Sourcepub fn set_start(&mut self, start: Date) -> Result<(), EntityError>
pub fn set_start(&mut self, start: Date) -> Result<(), EntityError>
Set the entity’s start Date if it’ll be valid
Sourcepub fn set_end(&mut self, end: Date) -> Result<(), EntityError>
pub fn set_end(&mut self, end: Date) -> Result<(), EntityError>
Set the entity’s end Date if it’ll be valid
Sourcepub fn end_year_is_set(&self) -> bool
pub fn end_year_is_set(&self) -> bool
Check if the entity’s end year is set
Sourcepub fn start_year(&self) -> Year
pub fn start_year(&self) -> Year
Check if the entity’s start year is set
Sourcepub fn start_month(&self) -> Option<Month>
pub fn start_month(&self) -> Option<Month>
Check if the entity’s start month is set
Sourcepub fn matches_bool_tag_expr(&self, bool_tag_expr: &BoolTagExpr) -> bool
pub fn matches_bool_tag_expr(&self, bool_tag_expr: &BoolTagExpr) -> bool
Whether the entity in question matches the boolean tag expression. This can be used to filter a list of entities by a boolean tag expression.