Name

Struct Name 

pub struct Name(/* private fields */);
The OpenTimeline Name type. The value can be any string apart from one which when trimmed of trailing and leading whitespace is empty.

Implementations

Source

impl Name

pub fn from<S: ToString>(name: S) -> Result<Self, NameError>

Create and initialise a new name if it will be valid

pub fn as_str(&self) -> &str

Get the underlying &str